/*
 * Copyright (C) 2014 Canonical, Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#include <cstdio>
#include "SelfServicePlanQuery.h"
#include <unity/scopes/SearchReply.h>
#include <unity/scopes/Category.h>
#include <unity/scopes/CategorisedResult.h>
#include "Utils.h"
#include "config.h"
#include <QtGlobal>
#include <QDebug>
#include <QFile>
#include <QJsonDocument>
#include <QJsonObject>
#include <QJsonArray>
#include <QList>
#include <QString>
#include <QVariant>

using namespace std;
using namespace unity::scopes;

SelfServicePlanQuery::SelfServicePlanQuery(Query const& query, QStringList const& scopes, QString const& locale)
    : SearchQuery(),
    query_(query),
    scopes_(scopes)
{
}

void SelfServicePlanQuery::run(SearchReplyProxy const& reply)
{
    CategoryRenderer renderer = CategoryRenderer::from_file((QString(SCOPE_INSTALL_DIR).append("/renderer.json")).toStdString());
    auto planCategory = reply->register_category("plan", _("Used so far this month"), "", renderer);

    QFile file;
    file.setFileName(QString(SCOPE_INSTALL_DIR).append("/selfserviceplan.json"));
    file.open(QIODevice::ReadOnly | QIODevice::Text);
    QString data = file.readAll();
    file.close();
    QJsonDocument doc = QJsonDocument::fromJson(data.toUtf8());
    if (doc.isNull())
        qWarning() << "JSON parsing failed";

    QJsonArray results = doc.array();

    for (int i = 0; i < results.size(); ++i)
    {     
        auto res = std::make_shared<CategorisedResult>(planCategory);
        
        auto value = results[i];
        auto obj = value.toObject();
        auto title = obj["title"].toString();
        auto uri = obj["link"].toString();
        auto image = obj["image"].toString();
        auto desc = obj["description"].toString();

        res->set_uri(uri.toStdString());
        res->set_title(title.toStdString());
        res->set_art(image.toStdString());
        res->set_dnd_uri(uri.toStdString());
        (*res)["summary"] = Variant(desc.toStdString());
        reply->push(*res);
    }
}

void SelfServicePlanQuery::cancelled()
{
   // Q_EMIT sss_client_->cancel();
}

