/* -*- mode: c; c-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Pawel Stolowski <pawel.stolowski@canonical.com>
 */

#include "SelfServicePlanScope.h"
#include "SelfServicePlanQuery.h"
#include <QCoreApplication>
#include <QStringList>
#include <QLocale>
#include <map>
#include <memory>
#include <string>
#include "Utils.h"
#include "config.h"

using namespace std;
using namespace unity::scopes;

#define EXPORT __attribute__ ((visibility ("default")))

extern "C" {

    EXPORT unity::scopes::ScopeBase* UNITY_SCOPE_CREATE_FUNCTION()
    {
        return new SelfServicePlanScope();
    }

    EXPORT void UNITY_SCOPE_DESTROY_FUNCTION(unity::scopes::ScopeBase* scope_base)
    {
        delete scope_base;
    }
}

SelfServicePlanScope::SelfServicePlanScope()
    : ScopeBase()
{
    bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
    textdomain(GETTEXT_PACKAGE);

    // determine locale for Smart Scopes queries
    m_locale = QLocale::system().name();

    int argc = 1;
    char *argv[1] = {nullptr};

    // an instance of Application is needed to avoid warnings from Qt
    m_app = new QCoreApplication(argc, argv);
}

SelfServicePlanScope::~SelfServicePlanScope()
{
    delete m_app;
}

int SelfServicePlanScope::start(string const&, unity::scopes::RegistryProxy const&)
{
    return VERSION;
}

QueryBase::UPtr SelfServicePlanScope::create_query(Query const& query, SearchMetadata const&)
{
    QStringList scopes;
    QueryBase::UPtr q(new SelfServicePlanQuery(query, scopes, m_locale));
    return q;
}

QueryBase::UPtr SelfServicePlanScope::preview(Result const& result,
                                              ActionMetadata const& hints)
{
    QueryBase::UPtr previewer(new SelfServicePlanPreview(*this, result));
    return previewer;
}

void SelfServicePlanScope::appendIfEnabled(QStringList &scopeToQuery, const QString &scopeId) const
{
    if (!m_disabledScopes.contains(scopeId)) {
        scopeToQuery << scopeId;
    }
}

void SelfServicePlanScope::updateDisabledScopes()
{
}

SelfServicePlanPreview::SelfServicePlanPreview(SelfServicePlanScope &scope, Result const &result)
    : scope(scope),
    result(result)
{
}

void SelfServicePlanPreview::cancelled() {
}

void SelfServicePlanPreview::run(PreviewReplyProxy const &reply) {
    ColumnLayout layout(1);
    layout.add_column({"art", "header", "description"});
    reply->register_layout({layout});

    PreviewWidget header("header", "header");
    header.add_component("title", "title");

    PreviewWidget art("art", "image");
    art.add_component("source", "art");

    PreviewWidget description("description", "text");
    description.add_component("text", "summary");

    reply->push({art, header, description,});
}
